==> Glossary-0.6.7.tar.gz: Glossary/lang/ext/de_DE.php <==
<?php
$lang['areyousure_altercontent'] = 'Wollen Sie diese Aktion wirklich ausf&uuml;hren? Ihre Inhalte werden dauerhaft ver&auml;ndert.';
$lang['filter_site_now'] = 'Jetzt filtern';
$lang['friendlyname'] = 'Glossary-/ W&ouml;rterbuch-/ FAQ-Modul';
$lang['postinstall'] = '<p>Stellen Sie sicher, dass die Benutzer, die mit Glossary arbeiten sollen, die Berechtigung &quot;Modify Glossary&quot; haben!</p>
<p>Sie werden sehr wahrscheinlich die Einstellungen &auml;ndern wollen. Ich habe absichtlich ungew&ouml;hnliche Einstellungen gew&auml;hlt, 
um die F&auml;higkeiten des Moduls zu demonstrieren. Aber Sie werden sicherlich mehr als f&uuml;nf Begriffe auf Ihrer Seite anzeigen
und meine Beispiel-Begriffe und -Kategorien l&ouml;schen wollen.';
$lang['postuninstall'] = 'Modul entfernt.';
$lang['uninstalled'] = 'Modul deinstalliert.';
$lang['installed'] = 'Modulversion %s installiert.';
$lang['prefsupdated'] = 'Moduleinstellungen aktualisiert.';
$lang['accessdenied'] = 'Zugriff verweigert. Bitte pr&uuml;fen Sie Ihre Berechtigungen.';
$lang['error'] = 'Fehler!';
$lang['upgraded'] = 'Modul auf Version %s aktualisiert.';
$lang['title_mod_prefs'] = 'Moduleinstellungen';
$lang['title_mod_admin'] = 'Modul-Administration';
$lang['title_term'] = 'Begriff';
$lang['title_definition'] = 'Definition';
$lang['column_definition'] = 'Definition';
$lang['title_default_template'] = 'Standard-Anzeige-Template';
$lang['title_default_single_term_template'] = 'Standard-Template f&uuml;r verlinkte Begriffe (wenn nur ein einzelner Begriff angezeigt werden soll)';
$lang['title_filter_site'] = 'Seite automatisch nach Begriffen filtern?';
$lang['title_filter_news'] = 'News-Artikel nach Begriffen filtern?';
$lang['title_number_show'] = 'Anzahl der pro Seite angezeigten Begriffe';
$lang['title_default_number_show'] = 'Voreingestellte Anzahl von Begriffen, die pro Seite angezeigt werden sollen';
$lang['title_filter_site_label'] = 'Alle Begriffe der Seite aktivieren? (Warnung - verlangsamt die Seitendarstellung)';
$lang['title_glossary_page'] = 'Glossary-Seite (Ziel f&uuml;r aktive Links)';
$lang['title_disable_prettyurls'] = 'Pretty URLs f&uuml;r dieses Modul deaktivieren';
$lang['title_disable_prettyurls_label'] = 'Deaktivieren';
$lang['title_glossary_inline'] = 'Die verlinkten Begriffe inline anzeigen?';
$lang['title_show_termids'] = 'Die ID&#039;s der Begriffe in der Administration anzeigen';
$lang['title_display_tab'] = 'Glossary-Seitenanzeige-Optionen';
$lang['title_single_term'] = 'Den verlinkten Begriff auf einer eigenen Seite anzeigen?';
$lang['title_single_term_label'] = 'Einzelne Begriffe anzeigen (als Gegensatz zu vollst&auml;ndigen Glossary-Anzeige)';
$lang['title_wysiwyg_definitions'] = 'Soll der WYSIWYG-Editor f&uuml;r die Eingabe der Begriffsdefinitionen verwendet werden?';
$lang['title_wysiwyg_terms'] = 'WYSIWYG f&uuml;r die Eingabe von Begriffen verwenden?';
$lang['title_wysiwyg_terms_help'] = 'Please note that markup inside terms can interfere with alphabetizing and with activated terms!';
$lang['title_link_tab'] = 'Glossary-Link-Optionen';
$lang['title_admin_tab'] = 'Administrations-Optionen';
$lang['title_filtering_tab'] = 'Optionen zur Begriffsfilterung';
$lang['title_number_spining_chars'] = 'Maximale Anzahl der Zeichen f&uuml;r die Anzeige des Begriffs in der Glossary-Navigation';
$lang['title_process_smarty'] = 'Smarty-Tags in Definitionen verarbeiten?';
$lang['filter_link'] = 'Link zur Glossary-Seite';
$lang['column_term'] = 'Begriff';
$lang['column_termid'] = 'Begriffs-ID';
$lang['column_action'] = 'Aktion';
$lang['column_category'] = 'Kategorie';
$lang['title_admin_panel'] = 'Glossary / W&ouml;rterbuch / FAQ';
$lang['title_term_list'] = 'Begriffe';
$lang['title_name'] = 'Name';
$lang['title_cats'] = 'Kategorien';
$lang['title_filter_category'] = 'Nur diese Kategorie anzeigen:';
$lang['title_all'] = 'Alle Kategorien';
$lang['column_template'] = 'Template-Name';
$lang['title_template'] = 'Template-Definition';
$lang['addterm'] = 'Einen neuen Begriff hinzuf&uuml;gen';
$lang['termadded'] = 'Der Begriff wurde hinzugef&uuml;gt.';
$lang['termdeleted'] = 'Der Begriff wurde gel&ouml;scht.';
$lang['edit'] = 'Den Begriff bearbeiten';
$lang['no'] = 'Nein';
$lang['yes'] = 'Ja';
$lang['filter'] = 'Filtern';
$lang['delete'] = 'Begriff l&ouml;schen';
$lang['suredelete'] = 'Wollen Sie den Begriff %s wirklich l&ouml;schen?';
$lang['listterms'] = 'Begriffe verwalten';
$lang['listtempl'] = 'Templates verwalten';
$lang['listcats'] = 'Kategorien verwalten';
$lang['addcat'] = 'Kategorie hinzuf&uuml;gen';
$lang['editcat'] = 'Kategorie bearbeiten';
$lang['delcat'] = 'Kategorie l&ouml;schen';
$lang['manageprefs'] = 'Administrator-Einstellungen';
$lang['templatelist'] = 'Templates';
$lang['unknown_term'] = 'Anfrage nach unbekanntem Begriff %s.';
$lang['glossary_page_help'] = 'W&auml;hlen Sie hier eine Seite, die einen Tag zur Anzeige der Informationen des Glossary-Moduls enth&auml;lt, z. Bsp. {cms_module module=&#039;Glossary&#039;}';
$lang['glossary_prettyurls_help'] = 'Die Deaktivierung der Pretty URLs kann m&ouml;glicherweise helfen, wenn einige Ihrer Begriffe nichtalphanumerische Zeichen oder Leerzeichen enthalten.';
$lang['glossary_inline_help'] = 'W&auml;hlen Sie diese Option, wenn die aktiven Begriffsdefinitionen inline angezeigt werden sollen. Dies ist mit der Verlinkung auf eine Glossary-Seite abgestimmt.';
$lang['title_glossary_inline_label'] = 'Inline anzeigen';
$lang['notemplates'] = 'Keine Templates in der Datenbank vorhanden.';
$lang['nocats'] = 'Keine Kategorien in der Datenbank vorhanden.';
$lang['addtemplate'] = 'Ein Template hinzuf&uuml;gen';
$lang['templateupdated'] = 'Das Template wurde aktualisiert';
$lang['templatedeleted'] = 'Das Template wurde gel&ouml;scht';
$lang['catupdated'] = 'Die Kategorie wurde aktualisiert';
$lang['catdeleted'] = 'Die Kategorie wurde gel&ouml;scht';
$lang['areyousure'] = 'Wollen Sie %s wirklich l&ouml;schen?';
$lang['next'] = ' : N&auml;chster &raquo;';
$lang['prev'] = '&laquo; Vorheriger : ';
$lang['moddescription'] = 'Mit diesem Modul k&ouml;nnen Sie eine Liste mit Begriffen und deren Definitionen erstellen und anzeigen lassen. Ein Begriff kann ein Wort, eine h&auml;ufig gestellte Frage oder etwas &auml;hnliches sein.';
$lang['changelog'] = '<ul>
<li>Version 0.6.6,  January 2009. Bug fixes, code refactoring, added &quot;random&quot; action, option to allow smarty tags in definitions, options for WYSIWYG.</li>
<li>Version 0.6.5,  January 2009. Bug fixes, now allows teplate specification to be name or id.</li>
<li>Version 0.6.4,  September 2008.  Adds glossary terms to the searchable content.  Bump minimum cms version to 1.4.1</li>
<li>Version 0.6.3,  March 2008.  Adds the ability to disable pretty urls for this module.  Bump minimum cms version to 1.2</li>
<li>Version 0.6.2.  December 2007.  Fixes a bug in preferences related to inline/non inline, bumps minimum cms version, Adds the RegisterModulePlugin call.</li>
<li>Version 0.6.1.  November 2007.  Adds functionality so that content never returns empty</li>
<li>Version 0.6. November 2007.  Adds a button to filter content and news on demand, splits it out into multiple files for reduced memory footprint.</li>
<li>Version 0.5.1. 28 Mar 2007.  Urls now validate. There ya go, Mr. InSiPiD.</li>
<li>Version 0.5. 8 November 2006. Removed pop-up window links, added inline display, and category filtering / requested features for InSiPiD.</li>
<li>Version 0.4. 7 November 2006. Updated for CMS MS 1.0.x, added features for InSiPiD.</li>
<li>Version 0.3. 24 October 2005. Bug fixes, new default template, more Admin configuration options.</li>
<li>Version 0.2. 20 October 2005. Initial Public Release.</li></ul>';
$lang['help_glossary_single'] = 'Einzelnen Begriff anzeigen';
$lang['help_glossary_tid'] = 'Term ID to highlight/emphasize';
$lang['help_glossary_catid'] = 'Restrict list to terms in category ID &quot;catid&quot;';
$lang['help_glossary_start'] = 'Offset in list to start listing terms';
$lang['help_glossary_term'] = 'Term to highlight/emphasize';
$lang['help_glossary_cat'] = 'Restrict list to terms in category &quot;cat&quot;';
$lang['help_glossary_template'] = 'Template name or ID to use to format terms';
$lang['help_glossary_term_count'] = 'Number of terms to show on a page (overrides default setting from admin)';
$lang['help_glossary_show_nav'] = 'Set to 0 to hide the pagination nav';
$lang['help_glossary_keyword'] = 'Restrict to terms whose definitions contain &quot;keyword&quot;';
$lang['help_glossary_sort'] = 'Sort order: currently only supports &quot;alpha&quot; or &quot;random&quot;';
$lang['help_glossary_no_pass_restrictions'] = 'To display a filtered or otherwise restricted list, but to have the expanded list not restricted, list the fields here (see example above)';
$lang['help'] = '<h3>Was macht dieses Modul?</h3>
<p>Mit diesem Modul kann eine Liste mit Begriffen erstellt werden, die dann auf einer Seite angezeigt werden. Nach einem Klick auf den Begriff wird die Anzeige um dessen Definition erweitert.</p>
<h3>Wie wird es eingesetzt ?</h3>
<h4>Standard-Glossary-Seite</h4>
<p>Um das Modul auf Ihrer Seite zu verwenden, f&uuml;gen Sie {cms_module module=&#039;Glossary&#039;} in Ihre Seite oder Template ein.</p>
<p>Mit den Parametern term=Term oder tid=term_id k&ouml;nnen Sie die Anzeige auf Ihrer Seite mit einem bestimmten, aktivierten Begriff starten.</p>
<p>Mit dem Parameter cat=&quot;Kategorie&quot; k&ouml;nnen Sie die Anzeige auf eine bestimmte Kategorie beschr&auml;nken.</p>
<p>Mit dem Parameter template=&quot;template_id&quot; k&ouml;nnen Sie die Einstellung des Standard-Templates &uuml;berschreiben.</p>
<p>Dieses Modul liest auch die URL und unterst&uuml;tzt die Spezifikationen der Parameter &quot;term&quot; oder &quot;cat&quot; in der URL. Sie haben zum Beispiel eine URL wie diese http://mysite/index.php?page=10?term=myterm. Wenn nun auf der Seite mit der ID 10 das Glossary-Modul aufgerufen wurde, wird der Begriff &quot;myterm&quot; und dessen Definition auf dieser Seite angezeigt.
<h3>Verlinkte Begriffe</h3>
<h4>&Uuml;berblick</h4>
<p>Sie k&ouml;nnen die Begriffe mit Links auf ihre Definition anzeigen lassen, die entweder &quot;inline&quot; angezeigt werden (der Inhalt der Seite wird durch die Begriffsdefinition ersetzt), oder auf Ihre Haupt-Glossary-Seite verlinkt sind. Die &quot;inline&quot;-Option kann im Abschnitt &quot;Glossary-Link-Optionen&quot; in der Moduladminstration eingestellt werden.</p>
<p>Au&szlig;erdem k&ouml;nnen Sie ausw&auml;hlen, ob auf eine separate Seite verlinkt werden soll, auf der nur die Definition des Begriffs angezeigt wird. De Anzeige k&ouml;nnen Sie &uuml;ber eine Anpassung des Templates ver&auml;ndern. Auch dies kann im Abschnitt &quot;Glossary-Link-Optionen&quot; in der Moduladminstration eingestellt werden.</p>
<h4>Einzelner Begriff</h4>
<p>Bei Bedarf k&ouml;nnen Sie auch bestimmte W&ouml;rter mit dem Glossary-Modul verlinken. F&uuml;gen Sie dazu den Tag &amp;#123;cms_module module=&#039;Glossary&#039; action=&#039;def&#039; term=&#039;foo&#039;} in Ihrer Seite ein und ersetzen &quot;foo&quot; mit einem im Glossary-Modul definierten Begriff.</p>
<h4>Ersetzen von Begriffen / Seitenfilterung</h4>
<p>Wenn Sie die Seitenfilterung aktivieren, erh&auml;lt jeder auf der Seite angezeigte Begriff einen Link. In Abh&auml;ngigkeit von dem in der Administration gew&auml;hlten Modus
erhalten Sie entweder einen Link zu Ihrer Haupt-Glossary-Seite oder einen Link zu dem angefragten Begriff.</p>
<p>Die Filterung von Seiten ist ein sehr aufwendiger Prozess, welcher die Darstellung der Seite enorm verlangsamt. Es gibt zwar eine alternative, schnellere Implementation, aber ich werde die aktuelle erst dann ersetzen, wenn gen&uuml;gend Beschwerden gekommen sind. Es ist wesentlich komplizierter und ich bin ein bi&szlig;chen faul, aber bei Bedarf werde ich dies nat&uuml;rlich beheben.</p>
<h3>Support</h3>
<p>Dieses Modul beinhaltet keinen kommerziellen Support. Sie k&ouml;nnen jedoch &uuml;ber folgende M&ouml;glichkeiten Hilfe zu dem Modul erhalten:</p>
<ul>
<li>F&uuml;r die letzte Version dieses Moduls, FAQs, dem Versand eines Fehlerreports oder dem Kauf kommerziellen Support besuchen Sie bitte Modul-Homepage im <a href="http://dev.cmsmadesimple.org/projects/glossary/">the CMS Forge</a>.</li>
<li>Eine weitere Diskussion zu diesem Modul ist auch in den Foren von <a href="http://forum.cmsmadesimple.org">CMS Made Simple</a> zu finden.</li>
<li>Der Autor SjG ist h&auml;ufig im <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a> zu finden.</li>
<li>Letztlich erreichen Sie den Autor auch &uuml;ber eine direkte Email.</li>  
</ul>
<p>Nach der GPL wird diese Software so ver&ouml;ffentlicht, wie sie ist. Bitte lesen Sie den Lizenztext f&uuml;r den vollen Haftungsausschluss.</p>

<h3>Copyright und Lizenz</h3>
<p>Copyright &copy; 2006, Samuel Goldstein <a href="mailto:sjg@cmsmodules.com"><sjg@cmsmodules.com></a>. Alle Rechte vorbehalten.</p>
<p>Dieses Modul wurde unter der <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a> ver&ouml;ffentlicht. Sie m&uuml;ssen dieser Lizenz zustimmen, bevor Sie das Modul verwenden.</p>';
$lang['utma'] = '156861353.717462736.1147511856.1238182852.1239477650.352';
$lang['utmz'] = '156861353.1234888676.321.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> Glossary-1.0.tar.gz: Glossary/lang/ext/de_DE.php <==
<?php
$lang['areyousure_altercontent'] = 'Wollen Sie diese Aktion wirklich ausf&uuml;hren? Ihre Inhalte werden unwiderruflich ver&auml;ndert.';
$lang['filter_site_now'] = 'Jetzt filtern';
$lang['friendlyname'] = 'Glossar / W&ouml;rterbuch / FAQ';
$lang['postinstall'] = '<p>Stellen Sie sicher, dass die Benutzer, die mit Glossary arbeiten sollen, die Berechtigung &quot;Modify Glossary&quot; haben!</p>
<p>Sie werden sehr wahrscheinlich die Einstellungen &auml;ndern wollen. Ich habe absichtlich ungew&ouml;hnliche Einstellungen gew&auml;hlt, 
um die F&auml;higkeiten des Moduls zu demonstrieren. Aber Sie werden sicherlich mehr als f&uuml;nf Begriffe auf Ihrer Seite anzeigen
und meine Beispiel-Begriffe und -Kategorien l&ouml;schen wollen.';
$lang['postuninstall'] = 'Das Modul wurde entfernt.';
$lang['uninstalled'] = 'Das Modul wurde deinstalliert.';
$lang['installed'] = 'Die Modulversion %s wurde installiert.';
$lang['prefsupdated'] = 'Die Moduleinstellungen wurden aktualisiert.';
$lang['accessdenied'] = 'Zugriff verweigert. Bitte pr&uuml;fen Sie Ihre Berechtigungen.';
$lang['error'] = 'Fehler!';
$lang['upgraded'] = 'Das Modul wurde auf Version %s aktualisiert.';
$lang['title_mod_prefs'] = 'Moduleinstellungen';
$lang['title_mod_admin'] = 'Modul-Administration';
$lang['title_term'] = 'Begriff';
$lang['title_tip'] = 'Tooltip / Link-Titel f&uuml;r den Begriff';
$lang['title_definition'] = 'Definition ';
$lang['column_definition'] = 'Definition ';
$lang['title_default_template'] = 'Standard-Anzeige-Template';
$lang['title_default_single_term_template'] = 'Standard-Template f&uuml;r verlinkte Begriffe (wenn nur ein einzelner Begriff angezeigt werden soll)';
$lang['title_filter_site'] = 'Seite automatisch nach Begriffen filtern?';
$lang['title_filter_news'] = 'News-Artikel nach Begriffen filtern?';
$lang['title_number_show'] = 'Anzahl der pro Seite angezeigten Begriffe';
$lang['title_default_number_show'] = 'Voreingestellte Anzahl von Begriffen, die pro Seite angezeigt werden sollen';
$lang['title_filter_site_label'] = 'Alle Begriffe der Seite aktivieren? (Warnung - verlangsamt die Seitendarstellung)';
$lang['title_glossary_page'] = 'Glossary-Seite (Ziel f&uuml;r aktive Links)';
$lang['title_disable_prettyurls'] = 'Pretty URLs f&uuml;r dieses Modul deaktivieren';
$lang['title_disable_prettyurls_label'] = 'Deaktivieren';
$lang['title_glossary_inline'] = 'Die verlinkten Begriffe inline anzeigen?';
$lang['title_show_termids'] = 'Die ID&#039;s der Begriffe in der Administration anzeigen';
$lang['title_display_tab'] = 'Glossary-Seitenanzeige-Optionen';
$lang['title_single_term'] = 'Den verlinkten Begriff auf einer eigenen Seite anzeigen?';
$lang['title_single_term_label'] = 'Einzelne Begriffe anzeigen (als Gegensatz zu vollst&auml;ndigen Glossary-Anzeige)';
$lang['title_wysiwyg_definitions'] = 'Soll der WYSIWYG-Editor f&uuml;r die Eingabe der Begriffsdefinitionen verwendet werden?';
$lang['title_wysiwyg_terms'] = 'WYSIWYG f&uuml;r die Eingabe von Begriffen verwenden?';
$lang['title_wysiwyg_terms_help'] = 'Bitte beachten Sie, dass das Markup innerhalb der Begriffe Auswirkungen auf die alphabetische Sortierung der aktivierten Begriffe haben kann!';
$lang['title_link_tab'] = 'Glossary-Link-Optionen';
$lang['title_admin_tab'] = 'Administrations-Optionen';
$lang['title_filtering_tab'] = 'Optionen zur Begriffsfilterung';
$lang['title_number_spining_chars'] = 'Maximale Anzahl der Zeichen f&uuml;r die Anzeige des Begriffs in der Glossary-Navigation';
$lang['title_process_smarty'] = 'Smarty-Tags in Definitionen verarbeiten?';
$lang['filter_link'] = 'Link zur Glossary-Seite';
$lang['column_term'] = 'Begriff';
$lang['column_termid'] = 'Begriffs-ID';
$lang['column_action'] = 'Aktion';
$lang['column_select'] = 'Ausw&auml;hlen';
$lang['column_category'] = 'Kategorie';
$lang['title_admin_panel'] = 'Glossary / W&ouml;rterbuch / FAQ';
$lang['title_term_list'] = 'Begriffe';
$lang['title_name'] = 'Name ';
$lang['title_cats'] = 'Kategorien';
$lang['title_filter_category'] = 'Nur diese Kategorie anzeigen:';
$lang['title_all'] = 'Alle Kategorien';
$lang['column_template'] = 'Template-Name';
$lang['title_template'] = 'Template-Definition';
$lang['addterm'] = 'Einen neuen Begriff hinzuf&uuml;gen';
$lang['termadded'] = 'Der Begriff wurde hinzugef&uuml;gt.';
$lang['termdeleted'] = 'Der Begriff wurde gel&ouml;scht.';
$lang['edit'] = 'Den Begriff bearbeiten';
$lang['no'] = 'Nein';
$lang['yes'] = 'Ja';
$lang['filter'] = 'Filtern';
$lang['delete'] = 'Begriff l&ouml;schen';
$lang['delete_selected'] = 'Ausgew&auml;hlte Begriffe l&ouml;schen';
$lang['areyousure_deletemultiple'] = 'Wollen Sie wirklich alle ausgew&auml;hlten Artikel l&ouml;schen?';
$lang['suredelete'] = 'Wollen Sie den Begriff %s wirklich l&ouml;schen?';
$lang['listterms'] = 'Begriffe verwalten';
$lang['listtempl'] = 'Templates verwalten';
$lang['listcats'] = 'Kategorien verwalten';
$lang['addcat'] = 'Kategorie hinzuf&uuml;gen';
$lang['editcat'] = 'Kategorie bearbeiten';
$lang['delcat'] = 'Kategorie l&ouml;schen';
$lang['manageprefs'] = 'Administrator-Einstellungen';
$lang['templatelist'] = 'Templates ';
$lang['unknown_term'] = 'Anfrage nach unbekanntem Begriff %s.';
$lang['glossary_page_help'] = 'W&auml;hlen Sie hier eine Seite, die einen Tag zur Anzeige der Informationen des Glossary-Moduls enth&auml;lt, z. Bsp. {cms_module module=&#039;Glossary&#039;}';
$lang['glossary_prettyurls_help'] = 'Die Deaktivierung der Pretty URLs kann m&ouml;glicherweise helfen, wenn einige Ihrer Begriffe nichtalphanumerische Zeichen oder Leerzeichen enthalten.';
$lang['glossary_inline_help'] = 'W&auml;hlen Sie diese Option, wenn die aktiven Begriffsdefinitionen inline angezeigt werden sollen. Dies ist mit der Verlinkung auf eine Glossary-Seite abgestimmt.';
$lang['title_glossary_inline_label'] = 'Inline anzeigen';
$lang['notemplates'] = 'Keine Templates in der Datenbank vorhanden.';
$lang['nocats'] = 'Keine Kategorien in der Datenbank vorhanden.';
$lang['addtemplate'] = 'Ein Template hinzuf&uuml;gen';
$lang['templateupdated'] = 'Das Template wurde aktualisiert';
$lang['templatedeleted'] = 'Das Template wurde gel&ouml;scht';
$lang['catupdated'] = 'Die Kategorie wurde aktualisiert';
$lang['catdeleted'] = 'Die Kategorie wurde gel&ouml;scht';
$lang['areyousure'] = 'Wollen Sie %s wirklich l&ouml;schen?';
$lang['next'] = ' : N&auml;chster &raquo;';
$lang['prev'] = '&laquo; Vorheriger : ';
$lang['moddescription'] = 'Mit diesem Modul k&ouml;nnen Sie eine Liste mit Begriffen und deren Definitionen erstellen und anzeigen lassen. Ein Begriff kann ein Wort, eine h&auml;ufig gestellte Frage oder etwas &auml;hnliches sein.';
$lang['help_glossary_single'] = 'Einzelnen Begriff anzeigen';
$lang['help_glossary_tid'] = 'Begriff-ID zum markieren/hervorheben';
$lang['help_glossary_catid'] = 'Liste zu Begriffen mit der Kategorie-ID &quot;catid&quot; beschr&auml;nken';
$lang['help_glossary_start'] = 'Versatz in der Liste, um Begriffliste zu starten ';
$lang['help_glossary_term'] = 'Begriff zum markieren/hervorheben';
$lang['help_glossary_cat'] = 'Liste zu Begriffen in der Kategorie &quot;cat&quot; beschr&auml;nken';
$lang['help_glossary_template'] = 'Name oder ID des Templates, welches f&uuml;r die Formatierung der Begriffe verwendet werden soll.';
$lang['help_glossary_term_count'] = 'Anzahl der auf einer Seite angezeigten Begriffe (&uuml;berschreibt die Voreinstellung in der Administration)';
$lang['help_glossary_show_nav'] = 'Auf 0 setzen, um Seitennummerierungs-Navigation zu verstecken';
$lang['help_glossary_keyword'] = 'Auf Begriffe beschr&auml;nken, deren Definitionen den &quot;Schl&uuml;sselbegriff&quot; enthalten.';
$lang['help_glossary_sort'] = 'Sortierreihenfolge: aktuell wird nur &quot;alpha&quot;, &quot;random&quot; (zuf&auml;llige Auswahl) und &quot;create_date&quot; (Erstellungsdatum) unterst&uuml;tzt.';
$lang['help_glossary_no_pass_restrictions'] = 'To display a filtered or otherwise restricted list, but to have the expanded list not restricted, list the fields here (siehe Beispiel oben)';
$lang['help_glossary_target'] = 'Alias der Seite, auf dem die Begriffe angezeigt werden sollen';
?>
